
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% PURPOSE:     Script file reading Excel file model options for Bayesian VARs      
%
% AUTHOR:      Mattias Villani, Research Department, Sveriges Riksbank and
%              Department of Statistics, Stockholm University. 
%              E-mail: mattias.villani@riksbank.se
%
% FIRST VER:   2003-09-17
% REVISED:     2007-09-08
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Defining the names of the Excel sheets.
endosheetname='Endo';
dummysheetname='Exo';
endopropsheetname='Endoproperties';
dummypropsheetname='Exoproperties';
RestrictionsSheetName='Identification';
CondForecastSheetName='CondForecast';

% Reading Excel files for parameter definitions, sample period, identifying restrictions, conditional forecasts etc
[NumericAddInfo,CharAddInfo] = xlsread(ExcelFileName,'Options');
[Grest,Labels]=xlsread(ExcelFileName,RestrictionsSheetName); % Contemporaneous restrictions
[NumericCondForecast,CharCondForecast] = xlsread(ExcelFileName,CondForecastSheetName); % Reading Excel file for inputs to conditional forecasting.

% Checking Matlab Version. Matlab 6 and 7 differ in the command xlsread.
MatlabVersion=ver;
for i=1:length(MatlabVersion)
    if strcmpi(MatlabVersion(i).Name,'matlab')==1
        MatlabPos=i;
    end
end
MatlabVersion=MatlabVersion(MatlabPos).Version;
MatlabVersion=str2double(MatlabVersion(1)); % First number in Matlab version, e.g. Matlab 6.5.1 returns MatlabVersion=6.

if MatlabVersion==8
    MatlabVersion=7;
end

switch MatlabVersion
    case 6
        % Do Nothing
    case 7
        % In Matlab6 NumericAddInfo contained NaN in the first positions where the cells contained strings
        % In Matlab7 these initial NaNs are not there and needs to be added manually for the code to handle
        % both Matlab 6 and 7. Also, in Matlab6, NumericAddInfo has two columns whereas in
        % Matlab7 it has only one. We add a column in Matlab7 for compatibility.
        Count=1;
        while (strcmpi(CharAddInfo{Count,2},'')==0);
            Count=Count+1;
        end
        NumericAddInfo=[nan*ones(Count-1,1);NumericAddInfo];
        if size(NumericAddInfo,2)==1
            NumericAddInfo=[NumericAddInfo NumericAddInfo];
        end
    otherwise
        ErrorMessage={'This package uses the Matlab command xlsread to read from Excel files.',...
            'This command appeared for the first time in Matlab 6. Your version of Matlab is older than version 6.',...
            'You must modify the file DSGEReadExcel.m or BVARReadExcel.m to read in data etc in some other way. Or upgrade Matlab ...'}
        errordlg(ErrorMessage,'Trouble, Trouble ...')
        return;
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  DATA OPTIONS %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
p=size(Grest,1);
ShockLabels=Labels(2:p+1,1);
variables=eval(strcat(CharAddInfo{2,2}));
dummies=eval(strcat(CharAddInfo{3,2}));
eststartyear=eval(strcat(CharAddInfo{4,2}(1:4)));
eststartperiod=eval(strcat(CharAddInfo{4,2}(6:end)));
estendyear1=eval(strcat(CharAddInfo{5,2}(1:4)));
estendperiod1=eval(strcat(CharAddInfo{5,2}(6:end)));
estendyear2=eval(strcat(CharAddInfo{6,2}(1:4)));
estendperiod2=eval(strcat(CharAddInfo{6,2}(6:end)));
season=NumericAddInfo(7,2);

AnnualizedGrowth=0; % This used to be an option in the program. Still define it as a safeguard.

switch CharAddInfo{8,2}
    case 'none'
        DeTrendVars=nan;
    otherwise
        DeTrendVars=eval(CharAddInfo{8,2});
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  MODEL AND PRIOR OPTIONS %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


K=NumericAddInfo(14,2);             % Lag length in VAR model.

switch CharAddInfo{15,2}
    case 'none'
        IncludeConstant=0;
        disp('Model estimated without constant')
    case 'standard'
        IncludeConstant=1;
        disp('Standard VAR')
    case 'meanadj'
        IncludeConstant=2; 
        disp('Steady State VAR')
    otherwise
        errordlg('Constant must be either none, standard, or meanadj','Error')
end

lambdas=NumericAddInfo(16:21,2);    % Prior hyperparameters. 1: Overall tightness, 2. Cross-variable tightness 3. lag length decay
                                    % 4. Exogenity tightness, 5. Dummy
                                    % tightness. 6. Seasonal tightness
if isnan(lambdas(6))
    PriorSeason=0;
else
    PriorSeason=season;
    disp('Special treatment of seasonal lags in prior')
end

if strcmpi(CharAddInfo{22,2},'yes')
    LoadPriorFromFile=1;
else
    LoadPriorFromFile=0;
end


if IncludeConstant==2
    Ndummies=length(dummies)+1;
    intervalcell=cell(Ndummies,1);
    [endoprop,endoproplabels]=xlsread(ExcelFileName,endopropsheetname);
    k=0;
    for i=1:Ndummies
        intervalcell{i}=endoprop(variables,5+k:6+k);
        k=k+2;
    end
    % Rearranging so that the constant dummy is last in the set of dummies.
    Temp=intervalcell{1}; % Temp now holds the prob intervals for the constant term
    for i=1:Ndummies-1
        intervalcell{i}=intervalcell{i+1};
    end
    intervalcell{Ndummies}=Temp;
end



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  POSTERIOR SAMPLING OPTIONS %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

niter=NumericAddInfo(25,2);                   % Number of draws from posterior.

if strcmpi(CharAddInfo{26,2},'none')
    LoadResultsFromFile=0;
else
    LoadResultsFromFile=1;
    SavedResultsFileName=CharAddInfo{26,2};
end

if strcmpi(CharAddInfo{27,2},'yes')
    ComputeLogPost=1;
else
    ComputeLogPost=0;
end

switch CharAddInfo{28,2}
    case 'none'
        LogMargLikeAlgo=0;
    case 'modharm'
        LogMargLikeAlgo=1;
    case 'chib'
        LogMargLikeAlgo=2;
    otherwise
        errordlg('Algorithm must be either none, modharm, or chib','Error')
end

switch CharAddInfo{29,2}
    case 'none'
        ML=0;
        disp('Bayesian Estimation')
    case 'unrestricted'
        disp('Maximum Likelihood Estimation - Unrestricted')
        ML=1;
    case 'blockFIML'
        disp('Maximum Likelihood Estimation - BlockFIML')
        ML=2;
    case 'blockQuasi'
        disp('Maximum Likelihood Estimation - BlockQuasi')
        ML=3;
    otherwise
end

if ML>0
    if IncludeConstant==2 % MLE are always computed for the model with constant in standard form.
        IncludeConstant=1;
    end
    warning off MATLAB:divideByZero % Disables warning message for division by zero.
end

if strcmpi(CharAddInfo{30,2},'yes')
    ForceStationarity=1;
else
    ForceStationarity=0;
end

PercentBurnin=NumericAddInfo(31,2);
ThinOutFreq=NumericAddInfo(32,2);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  FORECASTING OPTIONS %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

horizon=NumericAddInfo(35,2);                 % Forecasting horizon (dynamic predictions from time=1:horizon)

PlotForecast=NumericAddInfo(36,2);

if  strcmpi(CharAddInfo{37,2},'all')
    PredPlotVars=variables;
elseif strcmpi(CharAddInfo{37,2},'none')
    PredPlotVars=[];
else
    PredPlotVars=eval(strcat(CharAddInfo{37,2})); % Determines which variables are plotted in the prediction graph
end
PredVars=1:length(variables); % PredVars are here defined relative to variables. This says predict ALL variables used in the estimation.

%%%%%%%%%%% Begin reading input for conditional forecasting %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if  strcmpi(CharAddInfo{38,2},'none') 
    CondShock=[];
    CondHorizon{1}=[];
    CondVar=[];
    CondPath=[];
else
    CondShock=SemicolonSeparator2Cell(CharAddInfo{38,2});
    
    [NumericCondForecast,CharCondForecast] = xlsread(ExcelFileName,CondForecastSheetName);
    
    if isnan(NumericCondForecast(1,1))
        % do nothing
    else
        % Matlab has ignored the first row with labels in the Excel sheet. It does this at random!
        NumericCondForecast=[nan*ones(1,size(NumericCondForecast,2));NumericCondForecast];
    end
    HorizonCols=[];
    for j=1:length(CharCondForecast)
        if strcmpi(CharCondForecast{j},'Horizon')==1
            HorizonCols=[HorizonCols j];
        end
    end
    CondPathMatrix=NumericCondForecast(2:end,HorizonCols(1)+1:p+1);
    CondShockMatrix=NumericCondForecast(2:end,HorizonCols(2)+1:end);
    NColDiff=size(CondPathMatrix,2)-size(CondShockMatrix,2);
    if NColDiff>0
        CondShockMatrix=[CondShockMatrix nan*ones(size(CondShockMatrix,1),NColDiff)];
    end
    if all(all(isnan(CondPathMatrix)==isnan(CondShockMatrix)))==0
        errordlg('Bad correspondence between conditioning paths and the shocks needed to generate them','Error in inputs for conditional forecasting')
    end
    nBlocks=length(CondShock);
    CondHorizon=cell(nBlocks,1);
    CondPath=cell(nBlocks,1);
    CondVar=cell(nBlocks,1);
    
    for j=1:nBlocks
        [CurrentShockHorizon,Junk]=find(CondShockMatrix==j);
        CondHorizon{j}=sort(unique(CurrentShockHorizon));
        CondVar{j}=find(sum(CondShockMatrix==j));
        CondPath{j}=CondPathMatrix(CondHorizon{j},CondVar{j});
    end
end

if strcmpi(CharAddInfo{39,2},'yes')
    OtherShocks=1;
else
    OtherShocks=0;
end

%%%%%%%%%%% End reading input for conditional forecasting %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



%%%%%%%%%%% Begin reading input for historical decompositions %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if strcmpi(CharAddInfo{40,2},'none')
    HistDecompShocks{1}=nan;
else
    CharAddInfo{40,2}=['[;',CharAddInfo{40,2}(2:end)]; % Adding empty subset - to produce the baseline forecast without any shocks.
    HistDecompShocks=SemicolonSeparator2Cell(CharAddInfo{40,2});
end


if strcmpi(CharAddInfo{41,2},'first')
    HistDecompDate=[];
else
    HistDecompYear=eval(strcat(CharAddInfo{41,2}(1:4)));    
    HistDecompQuarter=eval(strcat(CharAddInfo{41,2}(6:end)));
    HistDecompDate=HistDecompYear+(1/season)*(HistDecompQuarter-1);
end

if  strcmpi(CharAddInfo{42,2},'all')
    DeCompVars=variables;
elseif strcmpi(CharAddInfo{42,2},'none')
    DeCompVars=[];
else
    DeCompVars=eval(CharAddInfo{42,2}); % Determines which variables are plotted in the HD graph
end

if  strcmpi(CharAddInfo{43,2},'all')
    DeCompScenarios=1:length(HistDecompShocks);
elseif strcmpi(CharAddInfo{43,2},'none')
    DeCompScenarios=[];
else
    DeCompScenarios=eval(CharAddInfo{43,2}); % Determines which scenarios are plotted in the HD graph
    DeCompScenarios=DeCompScenarios+1;
    DeCompScenarios=[1 DeCompScenarios]; % First scenario is the no-shock scenario.
end

if strcmpi(CharAddInfo{44,2},'yes')
    CondPathInAnnualGrowth=1;
else
    CondPathInAnnualGrowth=0;
end


%%%%%%%%%%%%%% End reading input from historical decompositions %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  FORECASTING EVALUATION OPTIONS %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

RMSEHorizons=eval(strcat(CharAddInfo{48,2}));      % Horizons where RMSE out-of-sample measure is computed.
PrintMeasures=eval(strcat(CharAddInfo{49,2}));     % Which univariate forecast accuracy measures should be printed to file?

if isnan(NumericAddInfo(50,2))          % NBackObs is the number of past observations in the RecentMean forecast. 
    NBackObs=eval(CharAddInfo{50,2});   % If NBackObs is a vector then every forecasting period uses different number of past observations.
else
    NBackObs=NumericAddInfo(50,2);
end

if strcmpi(CharAddInfo{51,2},'none')
    MSSESubsetVars{1}=nan;
elseif strcmpi(CharAddInfo{51,2},'all')
    MSSESubsetVars{1}=variables;
else
    MSSESubsetVars=SemicolonSeparator2Cell(CharAddInfo{51,2});
end

ScaleMatrixFile=CharAddInfo{52,2}; % Name of file containing the MSSE scaling matrix. If this is 'stdev', then scale matrix is diagonal matrix with standard deviations of FinalData (from FirstDateForScale to present) as elements. 

FirstDateForScale=CharAddInfo{53,2}; % Determines the first data observation used to compute the scale matrix in the log(det(MSE)) out-of-sample measure.

if  strcmpi(CharAddInfo{54,2},'all')
    CascadePlotVars=1:length(variables);
elseif strcmpi(CharAddInfo{54,2},'none')
    CascadePlotVars=[];
else
    CascadePlotVars=eval(strcat(CharAddInfo{54,2})); % Determines which variables are plotted in the cascade graph
end

CascadeSubPlots=NumericAddInfo(55,2);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% OPTIONS FOR ASSESSING MODEL FIT  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


if  strcmpi(CharAddInfo{61,2},'all')
    residualplotvars=1:length(variables);
elseif strcmpi(CharAddInfo{61,2},'none')
    residualplotvars=[];
else
    residualplotvars=eval(strcat(CharAddInfo{61,2})); % Determines which variables are plotted in the prediction graph
end

if strcmpi(CharAddInfo{62,2},'yes')
    EstMedian=1;
else
    EstMedian=0;
end

if strcmpi(CharAddInfo{63,2},'yes')
    actual_fitted=1;
else
    actual_fitted=0;
end

if strcmpi(CharAddInfo{64,2},'yes')
    crossplot=1;
else
    crossplot=0;
end

if strcmpi(CharAddInfo{65,2},'yes')
    actualres=1;
else
    actualres=0;
end

autocorrres=NumericAddInfo(66,2);
if autocorrres==0
    nlags=0;
    autocorrres=0;
else
    nlags=autocorrres;
    autocorrres=1;
end

if strcmpi(CharAddInfo{67,2},'yes')
    histores=1;
else
    histores=0;
end

if strcmpi(CharAddInfo{68,2},'yes')
    ComputeSteadyState=1;
else
    ComputeSteadyState=0;
end

if strcmpi(CharAddInfo{69,2},'yes')
    PlotSteadyState=1;
else
    PlotSteadyState=0;
end
if ComputeSteadyState==0
    PlotSteadyState=0;
end

if strcmpi(CharAddInfo{70,2},'yes')
    Convert2AnnualForFit=1;
else
    Convert2AnnualForFit=0;
end








%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%       STRUCTURAL VAR OPTIONS      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

switch CharAddInfo{73,2}
    case 'none'
        StructuralForm=0;
        disp('Reduced form analysis')
    case 'recursive'
        StructuralForm=1;
        disp('Recursive identifying restrictions')
    case 'non-recursive'
        StructuralForm=2; 
        disp('Non-recursive identifying restrictions')
        if ML==2 % Block recursive
            disp('Block recursive restrictions not implemented for non-recursive identification. Unrestricted ML used instead')
            ML=1;
        end
    otherwise
        errordlg('StructuralForm must be either none, non-recursive, or recursive','Error')
end

NormVars=eval(strcat(CharAddInfo{74,2})); % Normalizing Coefficients in Structural VAR
if isempty(NormVars) || any(isnan(NormVars))
    WZNorm=1;
else
    WZNorm=0;
end

IRHorizon=NumericAddInfo(75,2); % Impulse response horizon

if strcmpi(CharAddInfo{76,2},'yes')
    Convert2AnnualIR=1;
else
    Convert2AnnualIR=0;
end

if strcmpi(CharAddInfo{77,2},'yes') % DF correction of ML estimates under recursive identification
    DfCorrML=1;
else
    DfCorrML=0;
end 

if  strcmpi(CharAddInfo{78,2},'all') % Forecast Error Variance Decomposition (Horizon).
    FEVDHorizon=0:IRHorizon; % All horizons
elseif strcmpi(CharAddInfo{78,2},'none')
    FEVDHorizon=[];
else
    FEVDHorizon=eval(strcat(CharAddInfo{78,2}));
end
if StructuralForm==0 % No FEVD for reduced form
    FEVDHorizon=[];
end

if strcmpi(CharAddInfo{79,2},'yes')
    StoreStructShocks=1;
else
    StoreStructShocks=0;
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%       MISC OPTIONS      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Saving to file options
OutFileName=CharAddInfo{83,2};
datafilename=ExcelFileName;

if strcmpi(CharAddInfo{84,2},'yes')
    SaveParameters=1;
else
    SaveParameters=0;
end

if strcmpi(CharAddInfo{85,2},'yes')
    estsum=1;
else
    estsum=0;
end

lengthofpast=NumericAddInfo(86,2);  % Number of time periods to be plotted before the prediction period.

if strcmpi(CharAddInfo{87,2},'yes')
    HPD=1;
else
    HPD=0;
end

LongRunCoverProb=NumericAddInfo(88,2);

CoverProb=eval(strcat(CharAddInfo{89,2}));          % Probability content of prediction intervals (equal mass in the tails).
if ML>0
    CoverProb=[];
end

LoopQuantity=CharAddInfo{90,2};
LoopValues=eval(strcat(CharAddInfo{91,2}));

if strcmpi(CharAddInfo{92,2},'yes')
    SwitchOffDuringSequential=0;
else
    SwitchOffDuringSequential=1;
end

if isnan(NumericAddInfo(93,2)) % RandSeed is a string
    RandSeed=0; % random seed
else % RandSeed is a number
    RandSeed=NumericAddInfo(93,2);
end

