function [Pi,Phi,Sigma]=mlvarmeanadj(X,D,K)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% PURPOSE: 	ML estimation of the parameters in the deterministic trend adjusted VAR model
%
% MODEL:    x_{t}-PHI*d_{t}=PI_{1}*(x_{t-1}-PHI*d_{t})+...+PI_{K}*(x_{t-K}-PHI*d_{t})+eps_{t}
%									
% INPUT:	X: 		    (T-by-p) matrix with T observations on p modelled variables.
%			D: 		    (T-by-q) matrix with T observations on q
%			             non-modelled variables. The program does NOT adds a column of ones for the constant in the process
%			k:          (scalar) number of lags in the VAR.
%           
% OUTPUT:	Pi         (niter-by-(p^2)*k) matrix of draws from the posterior of
%                       VAR coefficients.
%           Phi          (niter-by-p*q) matrix of draws from the posterior
%                       of the non-modelled variables.
%           Sigma       (niter-by-p*(p-1)/2) matrix of draws from the
%                       posterior of the covariance matrix of disturbances.
%
% AUTHOR:	Mattias Villani, Research Department, Sveriges Riksbank and Department of Statistics, Stockholm University.
%		    E-mail: mattias.villani@riksbank.se.
%
% DATE:		2003-11-12
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


[Y,X,D]=transform_to_multireg(X,D,K);
[T,p]=size(Y);
q=size(D,2);

Z=[X D];
Varml=inv(Z'*Z)*Z'*Y;
Pi=Varml(1:p*K,:); % ML estimate of Pi=[Pi{1},...,Pi_{k}]'
Cml=Varml(1+p*K:p*K+q,:); % ML estimate of constant'.
temp=eye(p);
for i=1:K % Computing I-PI1-PI2-...-PIK
    temp=temp-Pi(1+(i-1)*p:i*p,:);
end
Phi=(Cml*inv(temp))';
Sigma=(Y-Z*Varml)'*(Y-Z*Varml)/(T-p);
